%% Example of LFP signals and related spectrogram

function plotLFPSignal(LFP, fs_LFP)
    % Function to process and plot LFP signals and their spectrogram
    %
    % Inputs:
    % LFP - data of LFP signals (mV) 
    % fs_LFP - sample rate of LFP signal recording 

    % Create the timeline
    t2 = (1:length(LFP)) / fs_LFP; 
    %
    % Onputs:
    % Create a new figure
    figure
    
    % Plot LFP signals
    subplot(2,1,1);
    plot(t2, LFP, 'Color', '#e55709'); % (s)-(mV) 
    set(gca, 'TickDir', 'out');
    box off
    
    % Calculate and plot the spectrogram
    subplot(2,1,2);
    [~, f, time, P] = spectrogram(LFP*1000, hamming(256), 128, 1024, fs_LFP); % mV--μV
    imagesc(time, f, 10 * log10(abs(P))); % power spectrograms
    axis xy;
    ylim([0 100]);
    colormap jet; % Color scheme
    % Set the color axis scaling to specific dB values
    caxis([0 60]); % Adjust this range based on your data's dynamic range
    set(gca, 'TickDir', 'out');
    box off
end

% % Example usage
% LFP = ... % your LFP signal data %% the length of showing time is 55 s in our study
% fs_LFP = ... % your LFP sampling rate %%  1000 Hz in our study
% 
% plotLFPSignal(LFP, fs_LFP);